==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=zh
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>重要组:</b> 强烈建议从组中选择一个关键词.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => '站点管理员',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '编辑者',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => '在论坛上发表消息的站点访问者.',

	// I
	'icone_creation_groupe_mots' => '新建一个关键词组',
	'icone_creation_mots_cles' => '新建一个关键词',
	'icone_modif_groupe_mots' => '修改该词组',
	'icone_mots_cles' => '关键词',
	'icone_supprimer_groupe_mots' => '删除组',
	'icone_voir_tous_mots_cles' => '查看所有关键词',
	'info_articles_lies_mot' => '与关键词关联的文章',
	'info_changer_nom_groupe' => '改变组的名字:',
	'info_creation_mots_cles' => '在这里新建和配置站点关键词',
	'info_dans_groupe' => '组中',
	'info_delet_mots_cles' => '你被请求删除关键
<b>@titre_mot@</b> (@type_mot@). 关键词被连到
<b>@texte_lie@</b>你必须确认决定:', # MODIF
	'info_groupe_important' => '重要组',
	'info_mots_cles' => '关键词',
	'info_mots_cles_association' => '组中的关键词能被关联:',
	'info_oui_suppression_mot_cle' => '我要永久删除关键词.',
	'info_question_mots_cles' => '你希望站点使用关键词吗?',
	'info_qui_attribue_mot_cle' => '组中的关键词能被分配:',
	'info_retirer_mot' => '移动这个关键词',
	'info_retirer_mots' => '移去所有的关键词',
	'info_rubriques_liees_mot' => '与该关键词相关的专栏',
	'info_selection_un_seul_mot_cle' => '你一次从组中可选择 <b>只有一个关键词</b> .', # MODIF
	'info_supprimer_mot' => '删除小关键词',
	'info_titre_mot_cle' => '关键词的名字和标题',
	'info_un_mot' => '一次一个关键词',
	'item_ajout_mots_cles' => '认证论坛附加的关键词',
	'item_non_ajout_mots_cles' => '不认证论坛的新关键词',
	'item_non_utiliser_config_groupe_mots_cles' => '不使用关键词的高级配置',
	'item_non_utiliser_mots_cles' => '不使用关键词',
	'item_utiliser_config_groupe_mots_cles' => '使用关键词高级配置',
	'item_utiliser_mots_cles' => '使用关键词',

	// L
	'logo_mot_cle' => '关键词图标',

	// T
	'texte_config_groupe_mots_cles' => '你愿意激活关键词组的高级配置,
   详细说明, 例如每一组中能选中单一字
   ,一个组很重要...?', # MODIF
	'texte_mots_cles' => '关键词允许您创建与所处专栏位置无关的独立文章间的主题相关连接. 
这种方法能丰富站点的导航能力,甚至能使用这种属性定制您模板中的文章.',
	'texte_mots_cles_dans_forum' => '你愿意用户选择使用关键词, 在公众论坛中? (警告: 选项正确使用会更复杂.)', # MODIF
	'texte_nouveau_mot' => '新关键词',
	'titre_config_groupe_mots_cles' => '配置关键词组',
	'titre_gauche_mots_edit' => '关键词号:',
	'titre_mots_cles_dans_forum' => '公众论坛的关键词',
	'titre_mots_tous' => '关键词',
	'titre_nouveau_groupe' => '新组',
	'titre_page_mots_tous' => '关键词'
);

==> spip_4.4.11+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=zh
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>重要组:</b> 强烈建议从组中选择一个关键词.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => '站点管理员',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '编辑者',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => '在论坛上发表消息的站点访问者.',

	// I
	'icone_creation_groupe_mots' => '新建一个关键词组',
	'icone_creation_mots_cles' => '新建一个关键词',
	'icone_modif_groupe_mots' => '修改该词组',
	'icone_mots_cles' => '关键词',
	'icone_supprimer_groupe_mots' => '删除组',
	'icone_voir_tous_mots_cles' => '查看所有关键词',
	'info_articles_lies_mot' => '与关键词关联的文章',
	'info_changer_nom_groupe' => '改变组的名字:',
	'info_creation_mots_cles' => '在这里新建和配置站点关键词',
	'info_dans_groupe' => '组中',
	'info_delet_mots_cles' => '你被请求删除关键
<b>@titre_mot@</b> (@type_mot@). 关键词被连到
<b>@texte_lie@</b>你必须确认决定:', # MODIF
	'info_groupe_important' => '重要组',
	'info_mots_cles' => '关键词',
	'info_mots_cles_association' => '组中的关键词能被关联:',
	'info_oui_suppression_mot_cle' => '我要永久删除关键词.',
	'info_question_mots_cles' => '你希望站点使用关键词吗?',
	'info_qui_attribue_mot_cle' => '组中的关键词能被分配:',
	'info_retirer_mot' => '移动这个关键词',
	'info_retirer_mots' => '移去所有的关键词',
	'info_rubriques_liees_mot' => '与该关键词相关的专栏',
	'info_selection_un_seul_mot_cle' => '你一次从组中可选择 <b>只有一个关键词</b> .', # MODIF
	'info_supprimer_mot' => '删除小关键词',
	'info_titre_mot_cle' => '关键词的名字和标题',
	'info_un_mot' => '一次一个关键词',
	'item_ajout_mots_cles' => '认证论坛附加的关键词',
	'item_non_ajout_mots_cles' => '不认证论坛的新关键词',
	'item_non_utiliser_config_groupe_mots_cles' => '不使用关键词的高级配置',
	'item_non_utiliser_mots_cles' => '不使用关键词',
	'item_utiliser_config_groupe_mots_cles' => '使用关键词高级配置',
	'item_utiliser_mots_cles' => '使用关键词',

	// L
	'logo_mot_cle' => '关键词图标',

	// T
	'texte_config_groupe_mots_cles' => '你愿意激活关键词组的高级配置,
   详细说明, 例如每一组中能选中单一字
   ,一个组很重要...?', # MODIF
	'texte_mots_cles' => '关键词允许您创建与所处专栏位置无关的独立文章间的主题相关连接. 
这种方法能丰富站点的导航能力,甚至能使用这种属性定制您模板中的文章.',
	'texte_mots_cles_dans_forum' => '你愿意用户选择使用关键词, 在公众论坛中? (警告: 选项正确使用会更复杂.)', # MODIF
	'texte_nouveau_mot' => '新关键词',
	'titre_config_groupe_mots_cles' => '配置关键词组',
	'titre_gauche_mots_edit' => '关键词号:',
	'titre_mots_cles_dans_forum' => '公众论坛的关键词',
	'titre_mots_tous' => '关键词',
	'titre_nouveau_groupe' => '新组',
	'titre_page_mots_tous' => '关键词',
];
